#[repr(C)]pub struct AltBlockHeight {
pub chain_id: RawChainId,
pub height: usize,
}Expand description
Represents the height of a block on an alt-chain.
Size & Alignment
assert_eq!(size_of::<AltBlockHeight>(), 16);
assert_eq!(align_of::<AltBlockHeight>(), 8);Fields
chain_id: RawChainIdThe [ChainId] of the chain this alt block is on, in raw form.
height: usizeThe height of this alt-block.