#[repr(C)]pub struct AltChainInfo {
pub parent_chain: RawChain,
pub common_ancestor_height: usize,
pub chain_height: usize,
}Expand description
Information on an alternative chain.
Size & Alignment
assert_eq!(size_of::<AltChainInfo>(), 24);
assert_eq!(align_of::<AltChainInfo>(), 8);Fields
parent_chain: RawChainThe chain this alt chain forks from.
common_ancestor_height: usizeThe height of the first block we share with the parent chain.
chain_height: usizeThe chain height of the blocks in this alt chain.