#[repr(C)]pub struct BlockInfo {
pub cumulative_generated_coins: u64,
pub weight: usize,
pub cumulative_difficulty_low: u64,
pub cumulative_difficulty_high: u64,
pub block_hash: [u8; 32],
pub cumulative_rct_outs: u64,
pub long_term_weight: usize,
pub mining_tx_index: TxId,
pub prunable_blob_idx: u64,
pub v1_prunable_blob_idx: u64,
pub pruned_blob_idx: u64,
}Expand description
Block information.
Size & Alignment
assert_eq!(size_of::<BlockInfo>(), 112);
assert_eq!(align_of::<BlockInfo>(), 8);Fields
cumulative_generated_coins: u64The total amount of coins mined in all blocks so far, including this block’s.
weight: usizeThe adjusted block size, in bytes.
See block_weight.
cumulative_difficulty_low: u64Least-significant 64 bits of the 128-bit cumulative difficulty.
cumulative_difficulty_high: u64Most-significant 64 bits of the 128-bit cumulative difficulty.
block_hash: [u8; 32]The block’s hash.
cumulative_rct_outs: u64The total amount of RCT outputs so far, including this block’s.
long_term_weight: usizeThe long term block weight, based on the median weight of the preceding 100_000 blocks.
See long_term_weight.
mining_tx_index: TxIdTxId (u64) of the block coinbase transaction.
prunable_blob_idx: u64The index of the block blob in the v2 prunable tape.
v1_prunable_blob_idx: u64The index of the block blob in the v1 prunable tape.
pruned_blob_idx: u64The index of the block blob in the pruned tape.