#[repr(C)]pub struct PreRctOutputId {
pub amount: Amount,
pub amount_index: AmountIndex,
}Expand description
A identifier for a pre-RCT Output.
This can also serve as an identifier for RctOutput’s
when PreRctOutputId::amount is set to 0, although,
in that case, only AmountIndex needs to be known.
Size & Alignment
assert_eq!(size_of::<PreRctOutputId>(), 16);
assert_eq!(align_of::<PreRctOutputId>(), 8);Fields
amount: AmountAmount of the output.
This should be 0 if the output is an RctOutput.
amount_index: AmountIndexThe index of the output with the same amount.
In the case of Output’s, this is the index of the list
of outputs with the same clear amount.
In the case of RctOutput’s, this is the
global index of all RctOutputs
Implementations
Sourceimpl PreRctOutputId
impl PreRctOutputId
Sourcepub fn to_bytes(&self) -> [u8; 16]
pub fn to_bytes(&self) -> [u8; 16]
Serializes the PreRctOutputId into bytes.
Sourcepub fn from_bytes(bytes: &[u8; 16]) -> Self
pub fn from_bytes(bytes: &[u8; 16]) -> Self
Deserializes the bytes into a PreRctOutputId