#[repr(C)]pub struct TxInfo {
pub height: usize,
pub pruned_blob_idx: u64,
pub prunable_blob_idx: u64,
pub pruned_size: usize,
pub prunable_size: usize,
pub rct_output_start_idx: u64,
pub numb_rct_outputs: usize,
}Expand description
Information on a transaction in the blockchain.
Fields
height: usizeThe height of this transaction.
pruned_blob_idx: u64The index of the transactions pruned blob in the pruned tape.
prunable_blob_idx: u64The index of the transactions prunable blob in the corresponding prunable tape.
pruned_size: usizeThe size of the transactions pruned blob.
prunable_size: usizeThe size of th transaction prunable blob.
rct_output_start_idx: u64The index of the first V2 output in this transaction.
will be u64::MAX for V1 transactions.
numb_rct_outputs: usizeThe number of RCT outputs in this transaction.
Undefined for V1 transactions.
Implementations